@@ -10,15 +10,22 @@
 #include <KIO/ApplicationLauncherJob>
 #include <KIO/JobUiDelegate>
 
-ExternalAppModule::ExternalAppModule(QWidget *parent, KCModuleInfo *module)
+ExternalAppModule::ExternalAppModule(QWidget *parent, const KService::Ptr &module)
+    : module(module)
 {
     Q_UNUSED(parent)
 
     firstShow = true;
-    moduleInfo = module;
     externalModule.setupUi(this);
-    externalModule.LblText->setText(i18n("%1 is an external application and has been automatically launched", module->moduleName()));
-    externalModule.PbRelaunch->setText(i18n("Relaunch %1", module->moduleName()));
+    QString moduleName = module->name();
+    if (moduleName.isEmpty()) {
+        moduleName = module->property(QStringLiteral("X-KDE-PluginInfo-Name"), QVariant::String).toString();
+        if (!moduleName.isEmpty()) {
+            qWarning() << "Reading deprecated X-KDE-PluginInfo-Name property from ExternalAppModule, use Name property instead";
+        }
+    }
+    externalModule.LblText->setText(i18n("%1 is an external application and has been automatically launched", moduleName));
+    externalModule.PbRelaunch->setText(i18n("Relaunch %1", moduleName));
     connect(externalModule.PbRelaunch, &QPushButton::clicked, this, &ExternalAppModule::runExternal);
 }
 
@@ -37,7 +44,7 @@ void ExternalAppModule::showEvent(QShowEvent *event)
 
 void ExternalAppModule::runExternal()
 {
-    KIO::ApplicationLauncherJob *job = new KIO::ApplicationLauncherJob(moduleInfo->service());
+    KIO::ApplicationLauncherJob *job = new KIO::ApplicationLauncherJob(module);
     job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
     job->start();
 }
