@@ -111,11 +111,6 @@ public:
      */
     bool isDefaultsVisible() const;
 
-    /**
-     * Shows or hides the Reset button.
-     */
-    void setResetVisible(bool visible);
-
     /**
      * @returns True if the Reset button is visible.
      */
@@ -167,7 +162,8 @@ private:
     bool resolveChanges(KCModuleProxy *currentProxy);
     void addModule(MenuItem *item, const QStringList &args);
     bool moduleSave(KCModuleProxy *module);
-    void updatePageIconHeader(KPageWidgetItem *page, bool light = false);
+    void updatePageIconHeader(KPageWidgetItem *page);
+    void updateButtons();
 
 private Q_SLOTS:
     void activeModuleChanged(KPageWidgetItem *current, KPageWidgetItem *previous);
