@@ -27,9 +27,6 @@ class IconMode::Private
 {
 public:
     Private()
-        : categoryDrawer(nullptr)
-        , categoryView(nullptr)
-        , moduleView(nullptr)
     {
     }
 
@@ -38,14 +35,14 @@ public:
         delete aboutIcon;
     }
 
-    KCategoryDrawer *categoryDrawer;
-    KCategorizedView *categoryView;
-    QStackedWidget *mainWidget;
-    MenuModel *model;
-    MenuProxyModel *proxyModel;
-    KAboutData *aboutIcon;
-    ModuleView *moduleView;
-    QAction *backAction;
+    KCategoryDrawer *categoryDrawer = nullptr;
+    KCategorizedView *categoryView = nullptr;
+    QStackedWidget *mainWidget = nullptr;
+    MenuModel *model = nullptr;
+    MenuProxyModel *proxyModel = nullptr;
+    KAboutData *aboutIcon = nullptr;
+    ModuleView *moduleView = nullptr;
+    QAction *backAction = nullptr;
 };
 
 IconMode::IconMode(QObject *parent, const QVariantList &args)
@@ -138,7 +135,7 @@ void IconMode::changeModule(const QModelIndex &activeModule)
 {
     // Already loaded?
     MenuItem *item = activeModule.data(Qt::UserRole).value<MenuItem *>();
-    if(d->moduleView->activeModule() == &item->item())
+    if (d->moduleView->activeModuleName() == &item->name())
         return;
 
     changeModuleWithArgs(activeModule, QStringList());
@@ -207,7 +204,6 @@ void IconMode::initWidget()
     d->categoryView->setFrameShape(QFrame::NoFrame);
     d->categoryView->setModel(d->proxyModel);
     connect(d->categoryView, &QAbstractItemView::activated, this, &IconMode::changeModule);
-    connect(d->categoryView, &QAbstractItemView::clicked, this, &IconMode::changeModule);
 
     d->mainWidget->addWidget(d->categoryView);
     d->mainWidget->addWidget(d->moduleView);
