@@ -8,9 +8,8 @@
 #ifndef SYSTEMSETTINGSRUNNER_H
 #define SYSTEMSETTINGSRUNNER_H
 
-#include <KService>
-
 #include <KRunner/AbstractRunner>
+#include <QMutex>
 
 class SystemsettingsRunner : public Plasma::AbstractRunner
 {
@@ -18,7 +17,6 @@ class SystemsettingsRunner : public Plasma::AbstractRunner
 
 public:
     SystemsettingsRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
-    ~SystemsettingsRunner() override;
 
     void match(Plasma::RunnerContext &context) override;
     void run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &match) override;
@@ -26,8 +24,11 @@ public:
 protected Q_SLOTS:
     QMimeData *mimeDataForMatch(const Plasma::QueryMatch &match) override;
 
-protected:
-    void setupMatch(const KService::Ptr &service, Plasma::QueryMatch &action);
+private:
+    void setupMatch(const KPluginMetaData &data, Plasma::QueryMatch &match);
+    void matchNameKeywordAndGenericName(Plasma::RunnerContext &ctx);
+    QMutex m_mutex;
+    QList<KPluginMetaData> m_modules;
 };
 
 #endif
